@@ -1,6 +1,6 @@
 package Bundle::Phalanx100;
 
-$Bundle::Phalanx100::VERSION = '0.05';
+$Bundle::Phalanx100::VERSION = '0.07';
 
 1;
 
@@ -17,19 +17,55 @@ C<perl -MCPAN -e 'install "Bundle::Phalanx100"'>
 
 =head1 CONTENTS
 
-Digest::base  - not actually part of the Phalanx 100, but required by many modules
+Test::Harness
 
-Digest::MD5 - not actually part of the Phalanx 100, but required by many modules
+Test::Reporter
 
-Compress::Zlib
+Test::Builder
+
+Test::Builder::Tester
+
+Sub::Uplevel
+
+Test::Exception
+
+Test::Tester
+
+Test::NoWarnings
+
+Test::Tester
+
+Pod::Escapes
+
+Pod::Simple
+
+Test::Pod
 
 YAML
 
+Cwd
+
 Archive::Tar
 
 Module::Build
 
-Mime::Base64
+Devel::Symdump
+
+Pod::Coverage - needed for Test::Pod::Coverage
+
+Test::Pod::Coverage
+
+Compress::Zlib
+
+IO::Zlib
+
+Archive::Zip
+
+Archive::Tar
+
+Storable
+
+Digest::MD5
 
 URI
 
@@ -39,9 +75,7 @@ HTML::Parser
 
 LWP
 
-Term::ReadLine::Perl
-
-Test::Reporter
+IPC::Run
 
 CPANPLUS
 
@@ -49,97 +83,79 @@ DBI
 
 DBD::mysql
 
-Mail::Mailer
-
-Bit::Vector
-
-Date::Calc
-
-DBD::Oracle
-
-Digest::HMAC
-
-Digest::SHA1
-
 GD
 
+MIME::Base64
+
 Net::SSLeay
 
-IO::Socket::SSL
+Net::LDAP
 
-IO::Stringy
+XML::Parser 
 
-Mail::SpamAssassin
+Apache::ASP
 
-MIME::Lite
+CGI
 
-MIME::Tools
+Date::Manip
+
+DBD::Oracle
+
+DBD::Pg
+
+Digest::SHA1
+
+Digest::HMAC
+
+HTML::Tagset
+
+HTML::Template
+
+Net::Cmd
+
+Mail::Mailer
+
+MIME::Body
 
 Net::DNS
 
-Net::Telnet
-
-Parse::RecDescent
-
-Spreadsheet::WriteExcel
-
-XML::Parser
-
-AppConfig
-
-GD::Text
-
-GD::Graph
-
-Image::Info
-
-Image::Size
-
-XML::Parser::PerlSAX - libxml
-
-XML::DOM
-
-XML::XPath
-
-Template
-
-XML::Simple
+Time::HiRes
 
 Apache::DBI
 
 Apache::Session
 
-Archive::Zip
+Apache::Test
 
-SOAP::Lite
+AppConfig
 
-XML::Writer
+App::Info
 
-Bio::Perl
+Authen::PAM
 
-Error
+Authen::SASL
 
-Cache::Cache
+BerkeleyDB
 
-HTML::Template
+Bit::Vector
 
-CGI::Application
+Carp::Clan
 
-CGI::Kwiki
-
-CGI::Session
-
-List::Util
+Chart::Bars
 
 Class::DBI
 
-Class::Date
+Compress::Zlib::Perl
 
 Config::IniFiles
 
 Convert::ASN1
 
-Crypt::Blowfish
+Convert::TNEF
+
+Convert::UUlib
+
+CPAN
 
 Crypt::CBC
 
@@ -147,93 +163,157 @@ Crypt::DES
 
 Crypt::SSLeay
 
-Data::ShowTable
+Data::Dumper
 
-Date::Manip
+Date::Calc
 
-Text::CSV_XS
+DateTime
 
-DBD::CSV
+DBD::DB2
 
 DBD::ODBC
 
-DBD::Pg
+DBD::SQLite
 
-DBIx::SearchBuilder
+DBD::Sybase
 
-IO::Tty
+Device::SerialPort
+
+Digest::SHA
+
+Encode
+
+Event
+
+Excel::Template
 
 Expect
 
-Params::Validate
+ExtUtils::MakeMaker
+
+File::Scan
+
+File::Spec
+
+File::Tail
+
+File::Temp
+
+GD::Graph
+
+GD::Text
+
+Getopt::Long
 
 HTML::Mason
 
-HTML::Tree
+Image::Size
+
+IMAP::Admin
+
+Parse::RecDescent
 
 Inline
 
-Apache::Request
+IO
 
-Mac::Carbon
+Spiffy
 
-Mac::Glue
+IO::All
 
-Mail::Box
+IO::Socket::SSL
+
+IO::String
+
+IO::Stringy
+
+XML::SAX2Perl
+
+Mail::Audit
+
+Mail::ClamAV
 
 Mail::Sendmail
 
+Math::Pari
+
 MD5
 
+MIME::Lite
+
 MP3::Info
 
-Msql
-
 Net::Daemon
 
+Net::FTP::Common
+
+Net::Ping
+
+Net::Server
+
 Net::SNMP
 
 Net::SSH::Perl
 
-PAR
+Net::Telnet
 
-PDF::API2
+OLE::Storage_Lite
 
-PDL
-
-Net::LDAP
+Params::Validate
 
 Image::Magick
 
-Pod::Simple
+RPC::PlServer
+
+Pod::Parser
 
 POE
 
-Regexp::Common
+SNMP
 
-SPOPS
+SOAP::Lite
 
 Spreadsheet::ParseExcel
 
+Spreadsheet::WriteExcel
+
+Spreadsheet::WriteExcelXML
+
+Storable
+
+Template
+
 Term::ReadKey
 
+Term::ReadLine::Perl
+
 Text::Iconv
 
-Text::Template
+Date::Parse
 
-Time::ParseDate
+Time::Timezone
 
-Time::Zone
+Unicode::String
+
+Unix::Syslog
+
+Verilog::Parser
 
 WWW::Mechanize
 
-XML::NamespaceSupport - not part of the "Phalanx 100" but required for XML::SAX and XML::LibXML
+XML::DOM
 
-
-XML::SAX
+XML::Generator
 
 XML::LibXML
 
+XML::NamespaceSupport
+
+XML::SAX
+
+XML::Simple
+
+XML::Writer
 
 =head1 DESCRIPTION
 
@@ -262,7 +342,7 @@ install a DBD module for a database not installed on the system.
 
 =head1 BUGS
 
-Currently, there are no known bug.  If you find any, patches are appreciated!
+Currently, there are no known bugs.  If you find any, patches are appreciated!
  
 =head1 AUTHOR
 
@@ -274,7 +354,7 @@ L<CPAN>, L<http://qa.perl.org/phalanx>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003, Steve Peters.  All Rights Reserved.
+Copyright (c) 2003-2005, Steve Peters.  All Rights Reserved.
 This module is free software.  It may be used, redistributed
 and/or modified under the same terms as Perl itself.
 
